@@ -7,9 +7,10 @@ from __future__ import annotations
 import json
 import logging
 import platform
+from collections.abc import Hashable
 from enum import Enum
 from pathlib import Path
-from typing import List, Tuple
+from typing import Any, TYPE_CHECKING, NoReturn, Callable
 
 from yaml import MappingNode
 from yaml import ScalarNode
@@ -27,14 +28,17 @@ from checkov.common.parsers.node import StrNode, DictNode, ListNode
 from checkov.common.util.consts import MAX_IAC_FILE_SIZE
 
 try:
-    from yaml.cyaml import CParser as Parser  # pylint: disable=ungrouped-imports
+    from yaml.cyaml import CParser as Parser  # type:ignore[attr-defined]
 
     cyaml = True
 except ImportError:
-    from yaml.parser import Parser  # pylint: disable=ungrouped-imports
+    from yaml.parser import Parser
 
     cyaml = False
 
+if TYPE_CHECKING:
+    from yaml import Node
+
 UNCONVERTED_SUFFIXES = ['Ref', 'Condition']
 FN_PREFIX = 'Fn::'
 
@@ -52,7 +56,7 @@ class CfnParseError(ConstructorError):
     Error thrown when the template contains Cfn Error
     """
 
-    def __init__(self, filename, message, line_number, column_number, key=' '):
+    def __init__(self, filename: str, message: str, line_number: int, column_number: int) -> None:
         # Call the base class constructor with the parameters it needs
         super(CfnParseError, self).__init__(message)
 
@@ -68,24 +72,28 @@ class NodeConstructor(SafeConstructor):
     Node Constructors for loading different types in Yaml
     """
 
-    def __init__(self, filename, content_type: ContentType = None):
+    def __init__(self, filename: str, content_type: ContentType | None = None) -> None:
         # Call the base class constructor
-        super(NodeConstructor, self).__init__()
-        self.add_constructor(
+        super().__init__()
+        self.add_constructor(  # type:ignore[type-var]
             u'tag:yaml.org,2002:map',
-            NodeConstructor.construct_yaml_map)
+            NodeConstructor.construct_yaml_map,
+        )
 
-        self.add_constructor(
+        self.add_constructor(  # type:ignore[type-var]
             u'tag:yaml.org,2002:str',
-            NodeConstructor.construct_yaml_str)
+            NodeConstructor.construct_yaml_str,
+        )
 
-        self.add_constructor(
+        self.add_constructor(  # type:ignore[type-var]
             u'tag:yaml.org,2002:seq',
-            NodeConstructor.construct_yaml_seq)
+            NodeConstructor.construct_yaml_seq,
+        )
         if content_type != ContentType.TFPLAN:
-            NodeConstructor.add_constructor(
+            NodeConstructor.add_constructor(  # type:ignore[type-var]
                 u'tag:yaml.org,2002:null',
-                NodeConstructor.construct_yaml_null_error)
+                NodeConstructor.construct_yaml_null_error,
+            )
         self.filename = filename
 
     # To support lazy loading, the original constructors first yield
@@ -93,16 +101,15 @@ class NodeConstructor(SafeConstructor):
     # laziness we omit this behaviour (and will only do "deep
     # construction") by first exhausting iterators, then yielding
     # copies.
-    def construct_yaml_map(self, node):
-
+    def construct_yaml_map(self, node: MappingNode) -> DictNode:
         # Check for duplicate keys on the current level, this is not desirable
         # because a dict does not support this. It overwrites it with the last
         # occurance, which can give unexpected results
         mapping = {}
         self.flatten_mapping(node)
         for key_node, value_node in node.value:
-            key = self.construct_object(key_node, False)
-            value = self.construct_object(value_node, False)
+            key = self.construct_object(key_node, False)  # type:ignore[no-untyped-call]
+            value = self.construct_object(value_node, False)  # type:ignore[no-untyped-call]
             try:
                 if isinstance(key, dict):
                     key = frozenset(key.keys()), frozenset(key.values())
@@ -110,36 +117,41 @@ class NodeConstructor(SafeConstructor):
                     key = frozenset(key)
             except TypeError:
                 raise CfnParseError(
-                    self.filename,
-                    f'Unable to construct key {key} (line {key_node.start_mark.line + 1})',
-                    key_node.start_mark.line, key_node.start_mark.column, key) from None
+                    filename=self.filename,
+                    message=f'Unable to construct key {key} (line {key_node.start_mark.line + 1})',
+                    line_number=key_node.start_mark.line,
+                    column_number=key_node.start_mark.column,
+                ) from None
             if key in mapping:
                 raise CfnParseError(
-                    self.filename,
-                    f'Duplicate resource found "{key}" (line {key_node.start_mark.line + 1})',
-                    key_node.start_mark.line, key_node.start_mark.column, key)
+                    filename=self.filename,
+                    message=f'Duplicate resource found "{key}" (line {key_node.start_mark.line + 1})',
+                    line_number=key_node.start_mark.line,
+                    column_number=key_node.start_mark.column,
+                )
             mapping[key] = value
 
-        obj, = SafeConstructor.construct_yaml_map(self, node)
+        obj, = SafeConstructor.construct_yaml_map(self, node)  # type:ignore[no-untyped-call]
         return DictNode(obj, node.start_mark, node.end_mark)
 
-    def construct_yaml_str(self, node):
-        obj = SafeConstructor.construct_yaml_str(self, node)
+    def construct_yaml_str(self, node: ScalarNode) -> StrNode:
+        obj = SafeConstructor.construct_yaml_str(self, node)  # type:ignore[no-untyped-call]
         assert isinstance(obj, str)  # nosec
         return StrNode(obj, node.start_mark, node.end_mark)
 
-    def construct_yaml_seq(self, node):
-        obj, = SafeConstructor.construct_yaml_seq(self, node)
+    def construct_yaml_seq(self, node: SequenceNode) -> ListNode:
+        obj, = SafeConstructor.construct_yaml_seq(self, node)  # type:ignore[no-untyped-call]
         assert isinstance(obj, list)  # nosec
         return ListNode(obj, node.start_mark, node.end_mark)  # nosec
 
-    def construct_yaml_null_error(self, node):
+    def construct_yaml_null_error(self, node: Node) -> NoReturn:
         """Throw a null error"""
         raise CfnParseError(
-            self.filename,
-            'Null value at line {0} column {1}'.format(
-                node.start_mark.line + 1, node.start_mark.column + 1),
-            node.start_mark.line, node.start_mark.column, ' ')
+            filename=self.filename,
+            message=f"Null value at line {node.start_mark.line + 1} column {node.start_mark.column + 1}",
+            line_number=node.start_mark.line,
+            column_number=node.start_mark.column,
+        )
 
 
 class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver):
@@ -149,7 +161,7 @@ class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver)
 
     # pylint: disable=non-parent-init-called,super-init-not-called
 
-    def __init__(self, stream, filename, content_type: ContentType = None):
+    def __init__(self, stream: str, filename: str, content_type: ContentType | None = None) -> None:
         Reader.__init__(self, stream)
         Scanner.__init__(self)
         if cyaml:
@@ -161,7 +173,7 @@ class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver)
         Resolver.__init__(self)
         NodeConstructor.__init__(self, filename, content_type)
 
-    def construct_mapping(self, node, deep=False):
+    def construct_mapping(self, node: MappingNode, deep: bool = False) -> dict[Hashable, Any]:
         mapping = super(MarkedLoader, self).construct_mapping(node, deep=deep)
         # Add 1 so line numbering starts at 1
         # mapping['__line__'] = node.start_mark.line + 1
@@ -170,13 +182,15 @@ class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver)
         return mapping
 
 
-def multi_constructor(loader, tag_suffix, node):
+def multi_constructor(loader: MarkedLoader, tag_suffix: str, node: ScalarNode) -> DictNode:
     """
     Deal with !Ref style function format
     """
 
+    constructor: Callable[[ScalarNode], Any]
+
     if tag_suffix not in UNCONVERTED_SUFFIXES:
-        tag_suffix = '{}{}'.format(FN_PREFIX, tag_suffix)
+        tag_suffix = f"{FN_PREFIX}{tag_suffix}"
 
     if tag_suffix == 'Fn::GetAtt':
         constructor = construct_getatt
@@ -198,7 +212,7 @@ def multi_constructor(loader, tag_suffix, node):
     return DictNode({tag_suffix: constructor(node)}, node.start_mark, node.end_mark)
 
 
-def construct_getatt(node):
+def construct_getatt(node: ScalarNode) -> ListNode:
     """
     Reconstruct !GetAtt into a list
     """
@@ -211,14 +225,14 @@ def construct_getatt(node):
     raise ValueError('Unexpected node type: {}'.format(type(node.value)))
 
 
-def loads(yaml_string, fname=None, content_type: ContentType = None):
+def loads(yaml_string: str, fname: str, content_type: ContentType | None = None) -> DictNode | dict[str, Any]:
     """
     Load the given YAML string
     """
     loader = MarkedLoader(yaml_string, fname, content_type)
-    loader.add_multi_constructor('!', multi_constructor)
+    loader.add_multi_constructor('!', multi_constructor)  # type:ignore[no-untyped-call]
 
-    template = loader.get_single_data()
+    template: "DictNode | dict[str, Any]" = loader.get_single_data()
     # Convert an empty file to an empty dict
     if template is None:
         template = {}
@@ -226,7 +240,7 @@ def loads(yaml_string, fname=None, content_type: ContentType = None):
     return template
 
 
-def load(filename: Path, content_type: ContentType) -> Tuple[DictNode, List[Tuple[int, str]]]:
+def load(filename: str | Path, content_type: ContentType) -> tuple[dict[str, Any], list[tuple[int, str]]]:
     """
     Load the given YAML file
     """
@@ -269,4 +283,4 @@ def load(filename: Path, content_type: ContentType) -> Tuple[DictNode, List[Tupl
             )
             return json.loads(content, cls=SimpleDecoder), file_lines
 
-    return loads(content, filename, content_type), file_lines
+    return loads(content, str(filename), content_type), file_lines
