@@ -4,16 +4,15 @@ import logging
 import os
 import json
 import itertools
-from json import JSONDecodeError
-from typing import Any, TYPE_CHECKING, cast
+from typing import Any, TYPE_CHECKING
 from collections import defaultdict
 
 import dpath.util
 
+from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.models.consts import SUPPORTED_FILE_EXTENSIONS
 from checkov.common.typing import _ReducedScanReport
 from checkov.common.util.json_utils import CustomJSONEncoder
-from botocore.exceptions import ClientError  # type:ignore[import]
 
 if TYPE_CHECKING:
     from botocore.client import BaseClient  # type:ignore[import]
@@ -24,6 +23,7 @@ checkov_results_prefix = 'checkov_results'
 check_reduced_keys = (
     'check_id', 'check_result', 'resource', 'file_path',
     'file_line_range')
+secrets_check_reduced_keys = check_reduced_keys + ('validation_status',)
 check_metadata_keys = ('evaluations', 'code_block', 'workflow_name', 'triggers', 'job')
 
 
@@ -36,31 +36,10 @@ def _put_json_object(s3_client: BaseClient, json_obj: Any, bucket: str, object_p
     try:
         s3_client.put_object(Bucket=bucket, Key=object_path, Body=json.dumps(json_obj, cls=CustomJSONEncoder))
     except Exception:
-        logging.error(f"failed to persist object {json_obj} into S3 bucket {bucket}", exc_info=True)
+        logging.error(f"failed to persist object into S3 bucket {bucket}", exc_info=True)
         raise
 
 
-def _get_json_object(
-    s3_client: BaseClient, bucket: str, object_path: str, throw_json_error: bool = True
-) -> dict[str, Any] | None:
-    try:
-        result_body = s3_client.get_object(Bucket=bucket, Key=object_path)['Body'].read().decode('utf-8')
-        return cast("dict[str, Any]", json.loads(result_body))
-    except ClientError:
-        logging.warning("failed to download json object", exc_info=True)
-    except JSONDecodeError as e:
-        if throw_json_error:
-            logging.error("Unable to decode downloaded JSON", exc_info=True)
-            raise e
-        else:
-            logging.warning("Failed to get json object", exc_info=True)
-    except Exception as e:
-        logging.error("Failed to get json object", exc_info=True)
-        raise e
-
-    return None
-
-
 def _extract_checks_metadata(report: Report, full_repo_object_key: str) -> dict[str, dict[str, Any]]:
     metadata: dict[str, dict[str, Any]] = defaultdict(dict)
     for check in itertools.chain(report.passed_checks, report.failed_checks, report.skipped_checks):
@@ -80,17 +59,19 @@ def reduce_scan_reports(scan_reports: list[Report]) -> dict[str, _ReducedScanRep
     """
     reduced_scan_reports: dict[str, _ReducedScanReport] = {}
     for report in scan_reports:
-        reduced_scan_reports[report.check_type] = \
+        check_type = report.check_type
+        reduced_keys = secrets_check_reduced_keys if check_type == CheckType.SECRETS else check_reduced_keys
+        reduced_scan_reports[check_type] = \
             {
                 "checks": {
                     "passed_checks": [
-                        {k: getattr(check, k) for k in check_reduced_keys}
+                        {k: getattr(check, k) for k in reduced_keys}
                         for check in report.passed_checks],
                     "failed_checks": [
-                        {k: getattr(check, k) for k in check_reduced_keys}
+                        {k: getattr(check, k) for k in reduced_keys}
                         for check in report.failed_checks],
                     "skipped_checks": [
-                        {k: getattr(check, k) for k in check_reduced_keys}
+                        {k: getattr(check, k) for k in reduced_keys}
                         for check in report.skipped_checks]
                 },
                 "image_cached_results": report.image_cached_results
