@@ -1,13 +1,16 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable, Dict, TypeVar, Set
+from typing import TYPE_CHECKING, Any, Callable, Dict, TypeVar, Set, Union
 from typing_extensions import TypeAlias, TypedDict
 
 if TYPE_CHECKING:
     from checkov.common.bridgecrew.severities import Severity
     from checkov.common.checks.base_check import BaseCheck
+    from checkov.common.graph.db_connectors.db_connector import DBConnector
     from checkov.common.models.enums import CheckResult
     from checkov.common.runners.base_runner import BaseRunner  # noqa
+    from networkx import DiGraph
+    from igraph import Graph
 
 
 _BaseRunner = TypeVar("_BaseRunner", bound="BaseRunner[Any]")
@@ -19,6 +22,8 @@ _ScannerCallableAlias: TypeAlias = Callable[
 _Resource: TypeAlias = str
 _Attributes: TypeAlias = Set[str]
 ResourceAttributesToOmit: TypeAlias = Dict[_Resource, _Attributes]
+LibraryGraph: TypeAlias = "Union[DiGraph, Graph]"
+LibraryGraphConnector: TypeAlias = "Union[DBConnector[DiGraph], DBConnector[Graph]]"
 
 
 class _CheckResult(TypedDict, total=False):
