@@ -13,6 +13,10 @@ _FUNCTION_NAME_CHARS = frozenset("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRST
 
 _ARG_VAR_PATTERN = re.compile(r"[a-zA-Z_]+(\.[a-zA-Z_]+)+")
 
+TERRAFORM_NESTED_MODULE_PATH_PREFIX = '([{'
+TERRAFORM_NESTED_MODULE_PATH_ENDING = '}])'
+TERRAFORM_NESTED_MODULE_PATH_SEPARATOR_LENGTH = 3
+
 
 @dataclass
 class VarBlockMatch:
@@ -306,14 +310,14 @@ def to_string(value: Any) -> str:
 def get_current_module_index(full_path: str) -> Optional[int]:
     hcl_index = None
     tf_index = None
-    if '[' not in full_path and '#' not in full_path:
+    if TERRAFORM_NESTED_MODULE_PATH_PREFIX not in full_path and '#' not in full_path:
         return len(full_path)
-    if '.hcl[' in full_path:
-        hcl_index = full_path.index('.hcl[') + 4  # len('.hcl')
+    if f'.hcl{TERRAFORM_NESTED_MODULE_PATH_PREFIX}' in full_path:
+        hcl_index = full_path.index(f'.hcl{TERRAFORM_NESTED_MODULE_PATH_PREFIX}') + 4  # len('.hcl')
     elif '.hcl#' in full_path:
         hcl_index = full_path.index('.hcl#') + 4  # len('.hcl')
-    if '.tf[' in full_path:
-        tf_index = full_path.index('.tf[') + 3    # len('.tf')
+    if f'.tf{TERRAFORM_NESTED_MODULE_PATH_PREFIX}' in full_path:
+        tf_index = full_path.index(f'.tf{TERRAFORM_NESTED_MODULE_PATH_PREFIX}') + 3    # len('.tf')
     elif '.tf#' in full_path:
         tf_index = full_path.index('.tf#') + 3  # len('.tf')
     if hcl_index and tf_index:
@@ -325,29 +329,29 @@ def get_current_module_index(full_path: str) -> Optional[int]:
 
 
 def is_nested(full_path: str) -> bool:
-    return '[' in full_path
+    return TERRAFORM_NESTED_MODULE_PATH_PREFIX in full_path
 
 
 def get_tf_definition_key(nested_module: str, module_name: str, module_index: Any, nested_key: str = '') -> str:
-    return f"{nested_module}[{module_name}#{module_index}{nested_key}]"
+    return f"{nested_module}{TERRAFORM_NESTED_MODULE_PATH_PREFIX}{module_name}#{module_index}{nested_key}{TERRAFORM_NESTED_MODULE_PATH_ENDING}"
 
 
 def get_tf_definition_key_from_module_dependency(path: str, module_dependency: str, module_dependency_num: str) -> str:
     if not module_dependency:
         return path
     if not is_nested(module_dependency):
-        return f"{path}[{module_dependency}#{module_dependency_num}]"
+        return f"{path}{TERRAFORM_NESTED_MODULE_PATH_PREFIX}{module_dependency}#{module_dependency_num}{TERRAFORM_NESTED_MODULE_PATH_ENDING}"
     module_index = get_current_module_index(module_dependency)
-    return f"{path}[{module_dependency[:module_index]}#{module_dependency_num}{module_dependency[module_index:]}]"
+    return f"{path}{TERRAFORM_NESTED_MODULE_PATH_PREFIX}{module_dependency[:module_index]}#{module_dependency_num}{module_dependency[module_index:]}{TERRAFORM_NESTED_MODULE_PATH_ENDING}"
 
 
 def get_module_from_full_path(file_path: str) -> Tuple[Optional[str], Optional[str]]:
     if not is_nested(file_path):
         return None, None
-    tmp_path = file_path[file_path.index('[') + 1: -1]
+    tmp_path = file_path[file_path.index(TERRAFORM_NESTED_MODULE_PATH_PREFIX) + TERRAFORM_NESTED_MODULE_PATH_SEPARATOR_LENGTH: -TERRAFORM_NESTED_MODULE_PATH_SEPARATOR_LENGTH]
     if is_nested(tmp_path):
-        module = get_abs_path(tmp_path) + tmp_path[tmp_path.index('['):]
-        index = tmp_path[tmp_path.index('#') + 1:tmp_path.index('[')]
+        module = get_abs_path(tmp_path) + tmp_path[tmp_path.index(TERRAFORM_NESTED_MODULE_PATH_PREFIX):]
+        index = tmp_path[tmp_path.index('#') + 1:tmp_path.index(TERRAFORM_NESTED_MODULE_PATH_PREFIX)]
     else:
         module = get_abs_path(tmp_path)
         index = tmp_path[tmp_path.index('#') + 1:]
