@@ -6,7 +6,7 @@ from collections.abc import Iterable
 from typing import TYPE_CHECKING
 
 from checkov.common.checks_infra.registry import get_graph_checks_registry
-from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
+from checkov.common.typing import LibraryGraphConnector
 from checkov.common.graph.graph_builder import CustomAttributes
 from checkov.common.graph.graph_builder.consts import GraphSource
 from checkov.common.images.image_referencer import ImageReferencerMixin
@@ -45,14 +45,14 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, list[_Instruction]]]"], B
 
     def __init__(
         self,
-        db_connector: NetworkxConnector | None = None,
+        db_connector: LibraryGraphConnector | None = None,
         source: str = GraphSource.DOCKERFILE,
         graph_class: type[DockerfileLocalGraph] = DockerfileLocalGraph,
         graph_manager: DockerfileGraphManager | None = None,
     ) -> None:
-        db_connector = db_connector or NetworkxConnector()
 
         super().__init__()
+        db_connector = db_connector or self.db_connector
         self.graph_class = graph_class
         self.graph_manager = (
             graph_manager if graph_manager else DockerfileGraphManager(source=source, db_connector=db_connector)
