@@ -13,7 +13,7 @@ class K8sGraphFlags:
     create_edges: bool
 
     def __init__(self, create_complex_vertices: bool = False, create_edges: bool = False) -> None:
-        create_complex_vertices_env_var: bool = bool(os.environ.get(CREATE_COMPLEX_VERTICES))
-        create_edges_env_var: bool = bool(os.environ.get(CREATE_EDGES))
+        create_complex_vertices_env_var: bool = bool(os.environ.get(CREATE_COMPLEX_VERTICES, True))
+        create_edges_env_var: bool = bool(os.environ.get(CREATE_EDGES, True))
         self.create_complex_vertices = create_complex_vertices or create_complex_vertices_env_var
         self.create_edges = create_edges or create_edges_env_var
