@@ -175,7 +175,7 @@ def create_cli_output(fixable: bool = True, *cve_records: list[Record]) -> str:
 def create_cli_license_violations_table(file_path: str, package_licenses_details_map: Dict[str, List[_LicenseStatus]]) -> str:
     package_table_lines: List[str] = []
     columns = 5
-    table_width = 120.0
+    table_width = 126
     column_width = int(table_width / columns)
     package_table = PrettyTable(min_table_width=table_width, max_table_width=table_width)
     package_table.set_style(SINGLE_BORDER)
@@ -234,8 +234,8 @@ def create_cli_license_violations_table(file_path: str, package_licenses_details
 
 def create_cli_cves_table(file_path: str, cve_count: CveCount, package_details_map: Dict[str, Dict[str, Any]]) -> str:
     columns = 6
-    table_width = 120
-    column_width = int(120 / columns)
+    table_width = 126
+    column_width = int(126 / columns)
 
     cve_table_lines = create_cve_summary_table_part(
         table_width=table_width, column_width=column_width, cve_count=cve_count
@@ -243,7 +243,7 @@ def create_cli_cves_table(file_path: str, cve_count: CveCount, package_details_m
 
     vulnerable_packages = True if package_details_map else False
     fixable_table_lines = create_fixable_cve_summary_table_part(
-        table_width=table_width, column_count=columns, cve_count=cve_count, vulnerable_packages=vulnerable_packages
+        table_width=table_width, cve_count=cve_count, vulnerable_packages=vulnerable_packages
     )
 
     package_table_lines = create_package_overview_table_part(
@@ -284,10 +284,10 @@ def create_cve_summary_table_part(table_width: int, column_width: int, cve_count
 
 
 def create_fixable_cve_summary_table_part(
-        table_width: int, column_count: int, cve_count: CveCount, vulnerable_packages: bool
+        table_width: int, cve_count: CveCount, vulnerable_packages: bool
 ) -> List[str]:
     fixable_table = PrettyTable(
-        header=False, min_table_width=table_width + column_count * 2, max_table_width=table_width + column_count * 2
+        header=False, min_table_width=table_width + 1, max_table_width=table_width + 1
     )
     fixable_table.set_style(SINGLE_BORDER)
     if cve_count.fixable:
