@@ -3,7 +3,7 @@ from typing import List, Dict, Any, Tuple
 
 from checkov.common.graph.graph_builder import CustomAttributes
 from checkov.common.runners.base_runner import strtobool
-from checkov.common.util.parser_utils import get_current_module_index, get_tf_definition_key, is_nested
+from checkov.common.util.parser_utils import get_tf_definition_key_from_module_dependency
 from checkov.terraform.graph_builder.graph_components.block_types import BlockType
 from checkov.terraform.graph_builder.graph_components.blocks import TerraformBlock
 
@@ -24,12 +24,7 @@ def convert_graph_vertices_to_tf_definitions(
 
         tf_path = block_path
         if vertex.module_dependency:
-            if is_nested(vertex.module_dependency):
-                module_index = get_current_module_index(vertex.module_dependency)
-                tf_path = get_tf_definition_key(block_path, vertex.module_dependency[:module_index],
-                                                vertex.module_dependency_num, vertex.module_dependency[module_index:])
-            else:
-                tf_path = get_tf_definition_key(block_path, vertex.module_dependency, vertex.module_dependency_num)
+            tf_path = get_tf_definition_key_from_module_dependency(block_path, vertex.module_dependency, vertex.module_dependency_num)
         tf_definitions.setdefault(tf_path, {}).setdefault(block_type, []).append(vertex.config)
         relative_block_path = f"/{os.path.relpath(block_path, root_folder)}"
         add_breadcrumbs(vertex, breadcrumbs, relative_block_path)
